#
# spec file for package libxfce4ui
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname_gtk2 libxfce4ui-1-0
%define libname_gtk3 libxfce4ui-2-0

Name:           libxfce4ui
Version:        4.12.1
Release:        4.2
Summary:        Widgets Library for the Xfce Desktop Environment
License:        LGPL-2.1+
Group:          System/Libraries
Url:            http://www.xfce.org/
Source0:        http://archive.xfce.org/src/xfce/libxfce4ui/4.12/%{name}-%{version}.tar.bz2
# needed until all applications have been ported to xfce_dialog_show_help() or
# an alternative mechanism
Source1:        xfhelp4.sh
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gladeui-1.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12
BuildRequires:  pkgconfig(libxfconf-0) >= 4.12
BuildRequires:  pkgconfig(sm)
# avoid circular dependency between libxfce4ui and exo
#!BuildIgnore:  exo-tools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The libxfce4ui library provides a number of widgets commonly used by Xfce
applications.

%package -n %{libname_gtk2}
Summary:        Widgets Library for the Xfce Desktop Environment
License:        LGPL-2.1+
Group:          System/Libraries
# uses exo-open
Requires:       exo-tools
# -branding only contains keyboard shortcuts for some libxfce4ui consumers so
# it is not really a dependency but it must be dragged in at a low level
Recommends:     %{name}-branding = %{version}
Recommends:     %{name}-lang = %{version}
Provides:       libxfce4ui = %{version}
Obsoletes:      libxfce4ui <= 4.8.1

%description -n %{libname_gtk2}
The libxfce4ui library provides a number of widgets commonly used by Xfce
applications. This package provides the GTK 2 variant of libxfce4ui.

%package -n %{libname_gtk3}
Summary:        Widgets Library for the Xfce Desktop Environment
License:        LGPL-2.1+
Group:          System/Libraries
# uses exo-open
Requires:       exo-tools
# -branding only contains keyboard shortcuts for some libxfce4ui consumers so
# it is not really a dependency but it must be dragged in at a low level
Recommends:     %{name}-branding = %{version}
Recommends:     %{name}-lang = %{version}

%description -n %{libname_gtk3}
The libxfce4ui library provides a number of widgets commonly used by Xfce
applications. This package provides the GTK 3 variant of libxfce4ui.

%package tools
Summary:        Tools from libxfce4ui
License:        GPL-2.0+
Group:          System/GUI/XFCE

%description tools
This package provides tools from libxfce4ui.

%package -n glade3-catalog-libxfce4ui
Summary:        Glade Catalog for libxfce4ui
License:        LGPL-2.1+
Group:          Development/Tools/GUI Builders
Requires:       %{libname_gtk2} = %{version}
Requires:       %{libname_gtk3} = %{version}
Requires:       glade3
Supplements:    packageand(glade3:%{name}-devel)

%description -n glade3-catalog-libxfce4ui
This package provides a catalog for Glade which allows the use of the provided
Xfce widgets in Glade.

%package devel
Summary:        Development Files for the libxfce4ui Library
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       %{libname_gtk2} = %{version}
Requires:       %{libname_gtk3} = %{version}
Recommends:     %{name}-doc = %{version}

%description devel
This package provides development files for developing applications based on
the libxfce4ui library.

%package doc
Summary:        Documentation for the libxfce4ui Library
License:        LGPL-2.1+
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package provides the documentation for the libxfce4ui library.

%package branding-upstream
Summary:        Upstream Branding of libxfce4ui
License:        GPL-2.0+
Group:          System/GUI/XFCE
Supplements:    packageand(%{libname_gtk2}:branding-upstream)
Supplements:    packageand(%{libname_gtk3}:branding-upstream)
# BRAND: xfce4-keyboard-shortcuts.xml: Controls the global keyboard shortcuts
# BRAND: for the Xfce desktop.
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for libxfce4ui.

# this should be replaced by %%lang_package once bnc#513786 is resolved
%package lang
Summary:        Languages for package %{name}
License:        LGPL-2.1+
Group:          System/Localization
Requires:       %{libname_gtk2} = %{version}
Requires:       %{libname_gtk3} = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    packageand(bundle-lang-other:%{libname_gtk2})
Supplements:    packageand(bundle-lang-other:%{libname_gtk3})
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%setup -q

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
    --enable-startup-notification \
    --with-vendor-info=openSUSE \
    --enable-gtk-doc \
    --disable-static
make %{?_smp_mflags} V=1

%install
%make_install

install -D -p -m 755 %{SOURCE1} %{buildroot}%{_bindir}/xfhelp4

find %{buildroot} -type f -name "*.la" -delete -print

%suse_update_desktop_file xfce4-about -r X-XFCE X-Xfce-Toplevel

# remove unsupported locales
rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

%fdupes %{buildroot}%{_includedir}

%post -n %{libname_gtk2} -p /sbin/ldconfig

%postun -n %{libname_gtk2} -p /sbin/ldconfig

%post -n %{libname_gtk3} -p /sbin/ldconfig

%postun -n %{libname_gtk3} -p /sbin/ldconfig

%post tools
%desktop_database_post
%icon_theme_cache_post

%postun tools
%desktop_database_postun
%icon_theme_cache_postun

%files -n %{libname_gtk2}
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README THANKS TODO
%{_libdir}/libxfce4ui-1.so.*
%{_libdir}/libxfce4kbd-private-2.so.*

%files -n %{libname_gtk3}
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README THANKS TODO
%{_libdir}/libxfce4ui-2.so.*
%{_libdir}/libxfce4kbd-private-3.so.*

%files lang -f %{name}.lang
%defattr(-,root,root)

%files -n glade3-catalog-libxfce4ui
%defattr(-, root, root)
%{_libdir}/glade3/modules/libxfce4uiglade.so
%{_datadir}/glade3/catalogs/libxfce4ui.xml*
%{_datadir}/glade3/pixmaps/hicolor/*/actions/*.png

%files devel
%defattr(-, root, root)
%{_libdir}/libxfce4ui-*.so
%{_libdir}/libxfce4kbd-private-*.so
%{_libdir}/pkgconfig/libxfce4ui-*.pc
%{_libdir}/pkgconfig/libxfce4kbd-private-*.pc
%{_includedir}/xfce4/libxfce4ui-1/
%{_includedir}/xfce4/libxfce4ui-2/
%{_includedir}/xfce4/libxfce4kbd-private-2/
%{_includedir}/xfce4/libxfce4kbd-private-3/

%files tools
%defattr(-, root, root)
%{_bindir}/xfhelp4
%{_bindir}/xfce4-about
%{_datadir}/applications/xfce4-about.desktop
%{_datadir}/icons/hicolor/48x48/apps/xfce4-logo.png

%files doc
%defattr(-, root, root)
%doc %{_datadir}/gtk-doc/html/libxfce4ui/

%files branding-upstream
%defattr(-, root, root)
%dir %{_sysconfdir}/xdg/xfce4
%dir %{_sysconfdir}/xdg/xfce4/xfconf
%dir %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml
%config %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-keyboard-shortcuts.xml

%changelog
* Sun Mar 15 2015 gber@opensuse.org
- update to version 4.12.1
  - fix glade directory information in .pc file (bxo#11353)
  - add shortcuts for xfwm4 to tile windows to corners (bxo#11652)
  - remove unused 'has_member' variable in xfce4-about (bxo#11654)
  - update .gitignore
  - increase xfce4-about default size
  - improve formatting of translators list
  - update translation contributors in xfce4-about
  - update contributors lists
  - translation updates
* Sun Mar  1 2015 Led <ledest@gmail.com>
- update BuildRequires
* Sun Mar  1 2015 Led <ledest@gmail.com>
- update BuildRequires
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - bump version
  - translation updates
* Thu Feb 19 2015 gber@opensuse.org
- update to version 4.11.2
  - bump dependencies versions (autotools, Xfce libraries)
  - remove SVN $Id$ tags
  - properly quote AC_LANG_SOURCE
  - fix autoconf m4 directory warning
  - fix IT_PROG_INTLTOOL warning
  - fix build with --enable-debug=full and GTK3 (bxo#11176)
  - add .gitignore
  - fix grabbing shortcuts with <Super> modifier (bxo#10373)
  - avoid double forking when spawning external apps (bxo#9373)
  - don't drop startup notify hint when resetting to defaults
    (bxo#10630)
  - add <Ctrl><Alt>l shortcut for screen locking (xflock4)
    (bxo#10728)
  - fix xfce_dialog_show_help()
* Wed Apr 30 2014 gber@opensuse.org
- update to version 4.11.1
  - add xfce_dialog_show_help_with_version() so applications can
    send their own version number and not the desktop version
  - compile GTK+-3 version of libxfce4ui when possible
  - depend on GTK 2.24 and Glib 2.28
  - only define distclean files in maintainer mode (bxo#8974)
  - don't remove keyboard shortcut when entered twice (bxo#8749)
  - fix keyboard shortcuts with Shift modifier (bxo#8744)
  - fix alt + print being detected as SysReq (bxo#7897)
  - use <Primary> instead of <Control> (bxo#8200)
  - fix keyboard shortcuts with keypad (bxo#4178)
  - autotools updates
  - prefer exo-open for opening the manual pages
  - add error domain for XfceSmClient
  - translation updates
- add subpackage libxfce4ui-2-0 with the GTK3 variant of libxfce4ui
* Mon Oct 15 2012 gber@opensuse.org
- avoid circular dependency between libxfce4ui and exo
* Wed May  9 2012 gber@opensuse.org
- add versioned build dependency
* Mon May  7 2012 gber@opensuse.org
- bring back xfhelp4 since it is still needed until all
  applications have been ported to xfce_dialog_show_help() or an
  alternative mechanism
* Thu May  3 2012 gber@opensuse.org
- fix license of libxfce4ui-tools (bnc#760492)
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - update contributor credits
  - enable startup notification in xfce4-appfinder shortcuts
  - translation updates
- make libxfce4ui-1-0 depend on exo-tools, it uses exo-open
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.2
  - increase gtk and glib versions
  - bump 4util dependency
  - remove unused function prototype
  - translation updates
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.1
  - open docs.xfce.org when Help in xfce4-about is clicked
  - cache header icons and avoid large icons in XfceTitledDialog
  - restore glade directory information in .pc file
  - update translator credits
  - a lot of improvements in the shortcuts code
  - add Alt + F1 as a shortcut for applications menu
  - remove unused code from the internal header widget
  - add xfce4-about from xfce-utils package
  - use xdt-csource instead of exo-csource, depend on xdt 4.9.0
  - update to new xfce4-appfinder commands
  - fix build against 3.9 Glade
  - add shortcuts for XF86WWW and XF86Mail
  - simplify the xfce_gdk_screen_get_active fucntion
  - add xfce_dialog_show_help function
  - translation updates
- dropped libxfce4ui-fix-shortcut-handling.patch which is not
  applicable any more
- split off -tools subpackage
* Sat Mar 31 2012 gber@opensuse.org
- recommending the branding package is enough
* Sat Mar 24 2012 gber@opensuse.org
- split off libxfce4ui-1-0 subpackage in order to conform to the
  shared library packaging policy
- specfile cleanup
- added libxfce4ui-fix-shortcut-handling.patch which normalizes
  string representation of keyboard shortcuts before comparing them
  in the libxfce4kbd-private shortcut matching code
* Fri Dec 23 2011 gber@opensuse.org
- updated to version 4.8.1
  - fix memory leak
  - translation updates
* Fri Oct 14 2011 gber@opensuse.org
- recommend -doc subpackage
* Sun Jan 30 2011 gber@opensuse.org
- improved summaries/descriptions
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.0
  - bugfixes
- dropped
  libxfce4ui-4.7.6-fix-libxfce4kbd-private-buffer-overflow.patch
  since the problem has been fixed
* Wed Jan  5 2011 gber@opensuse.org
- added -branding-upstream subpackage
* Tue Jan  4 2011 gber@opensuse.org
- added
  libxfce4ui-4.7.6-fix-libxfce4kbd-private-buffer-overflow.patch
  which fixes a buffer overflow in libxfce4kbd-private that was
  causing crashes on first startup
- updated to 4.7.6
  - update default shortcuts for xfce4-display-settings
* Fri Dec 24 2010 gber@opensuse.org
- improved descriptions
- corrected categories
- removed unsupported locales
- show compiler output
* Sun Dec  5 2010 prusnak@opensuse.org
- updated to 4.7.5
  - Also request an interact for save-state-extended.
  - Return a NULL state file is the sm-client is disabled.
  - Fix the save-state signal.
  - Translation updates (pt).
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Mon Nov 22 2010 andrea@opensuse.org
- update to 4.7.4
  * Translations update
  * Make g_critical warning about exit(0) a DBG message
  * Fix typo preventing shortcuts from working with new users
  * Add startup notification support for shortcuts
  * Only save startup-notify if enabled
* Tue Oct  5 2010 vuntz@opensuse.org
- Split glade3 catalog in a glade3-catalog-libxfce4ui subpackage.
  Part of bnc#637694.
* Thu Jul 22 2010 andrea@opensuse.org
- exclude the file xfce4-keyboard-shortcuts.xml because conflits
  with the same provided by libxfcegui4
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 4.7.1
  - New function xfce_spawn_on_screen_with_child_watch().
  - Don't generate enums for XfceSMClientPriority.
  - Build ChangeLog during make dist.
  - Add visibility/alias handing code.
  - Rename configure.in.in to configure.ac.in.
  - Some other small fixes.
  - Translation updates (es, pt_BR, sv, pt, kk, ca, gl, sk, cs, lv, eu,
    zh_CN, ja).
* Fri Nov 13 2009 prusnak@suse.cz
- created package (version 4.7.0)
